# -*- coding: utf-8 -*-
from django.views.generic import DetailView, ListView, UpdateView, CreateView
from .models import Dialog, DialogVar, Acc, AccCdr, MissedCall, UacReg, Trusted, Version, Location, LocationAttrs, UserBlackList, GlobalBlackList, SpeedDial, PipeLimit, Mtree, Mtrees, Htable, RtpEngine, Statistic
from .forms import DialogForm, DialogVarForm, AccForm, AccCdrForm, MissedCallForm, UacRegForm, TrustedForm, VersionForm, LocationForm, LocationAttrsForm, UserBlackListForm, GlobalBlackListForm, SpeedDialForm, PipeLimitForm, MtreeForm, MtreesForm, HtableForm, RtpEngineForm, StatisticForm


class DialogListView(ListView):
    model = Dialog


class DialogCreateView(CreateView):
    model = Dialog
    form_class = DialogForm


class DialogDetailView(DetailView):
    model = Dialog


class DialogUpdateView(UpdateView):
    model = Dialog
    form_class = DialogForm


class DialogVarListView(ListView):
    model = DialogVar


class DialogVarCreateView(CreateView):
    model = DialogVar
    form_class = DialogVarForm


class DialogVarDetailView(DetailView):
    model = DialogVar


class DialogVarUpdateView(UpdateView):
    model = DialogVar
    form_class = DialogVarForm


class AccListView(ListView):
    model = Acc


class AccCreateView(CreateView):
    model = Acc
    form_class = AccForm


class AccDetailView(DetailView):
    model = Acc


class AccUpdateView(UpdateView):
    model = Acc
    form_class = AccForm


class AccCdrListView(ListView):
    model = AccCdr


class AccCdrCreateView(CreateView):
    model = AccCdr
    form_class = AccCdrForm


class AccCdrDetailView(DetailView):
    model = AccCdr


class AccCdrUpdateView(UpdateView):
    model = AccCdr
    form_class = AccCdrForm


class MissedCallListView(ListView):
    model = MissedCall


class MissedCallCreateView(CreateView):
    model = MissedCall
    form_class = MissedCallForm


class MissedCallDetailView(DetailView):
    model = MissedCall


class MissedCallUpdateView(UpdateView):
    model = MissedCall
    form_class = MissedCallForm


class UacRegListView(ListView):
    model = UacReg


class UacRegCreateView(CreateView):
    model = UacReg
    form_class = UacRegForm


class UacRegDetailView(DetailView):
    model = UacReg


class UacRegUpdateView(UpdateView):
    model = UacReg
    form_class = UacRegForm


class TrustedListView(ListView):
    model = Trusted


class TrustedCreateView(CreateView):
    model = Trusted
    form_class = TrustedForm


class TrustedDetailView(DetailView):
    model = Trusted


class TrustedUpdateView(UpdateView):
    model = Trusted
    form_class = TrustedForm


class VersionListView(ListView):
    model = Version


class VersionCreateView(CreateView):
    model = Version
    form_class = VersionForm


class VersionDetailView(DetailView):
    model = Version


class VersionUpdateView(UpdateView):
    model = Version
    form_class = VersionForm


class LocationListView(ListView):
    model = Location


class LocationCreateView(CreateView):
    model = Location
    form_class = LocationForm


class LocationDetailView(DetailView):
    model = Location


class LocationUpdateView(UpdateView):
    model = Location
    form_class = LocationForm


class LocationAttrsListView(ListView):
    model = LocationAttrs


class LocationAttrsCreateView(CreateView):
    model = LocationAttrs
    form_class = LocationAttrsForm


class LocationAttrsDetailView(DetailView):
    model = LocationAttrs


class LocationAttrsUpdateView(UpdateView):
    model = LocationAttrs
    form_class = LocationAttrsForm


class UserBlackListListView(ListView):
    model = UserBlackList


class UserBlackListCreateView(CreateView):
    model = UserBlackList
    form_class = UserBlackListForm


class UserBlackListDetailView(DetailView):
    model = UserBlackList


class UserBlackListUpdateView(UpdateView):
    model = UserBlackList
    form_class = UserBlackListForm


class GlobalBlackListListView(ListView):
    model = GlobalBlackList


class GlobalBlackListCreateView(CreateView):
    model = GlobalBlackList
    form_class = GlobalBlackListForm


class GlobalBlackListDetailView(DetailView):
    model = GlobalBlackList


class GlobalBlackListUpdateView(UpdateView):
    model = GlobalBlackList
    form_class = GlobalBlackListForm


class SpeedDialListView(ListView):
    model = SpeedDial


class SpeedDialCreateView(CreateView):
    model = SpeedDial
    form_class = SpeedDialForm


class SpeedDialDetailView(DetailView):
    model = SpeedDial


class SpeedDialUpdateView(UpdateView):
    model = SpeedDial
    form_class = SpeedDialForm


class PipeLimitListView(ListView):
    model = PipeLimit


class PipeLimitCreateView(CreateView):
    model = PipeLimit
    form_class = PipeLimitForm


class PipeLimitDetailView(DetailView):
    model = PipeLimit


class PipeLimitUpdateView(UpdateView):
    model = PipeLimit
    form_class = PipeLimitForm


class MtreeListView(ListView):
    model = Mtree


class MtreeCreateView(CreateView):
    model = Mtree
    form_class = MtreeForm


class MtreeDetailView(DetailView):
    model = Mtree


class MtreeUpdateView(UpdateView):
    model = Mtree
    form_class = MtreeForm


class MtreesListView(ListView):
    model = Mtrees


class MtreesCreateView(CreateView):
    model = Mtrees
    form_class = MtreesForm


class MtreesDetailView(DetailView):
    model = Mtrees


class MtreesUpdateView(UpdateView):
    model = Mtrees
    form_class = MtreesForm


class HtableListView(ListView):
    model = Htable


class HtableCreateView(CreateView):
    model = Htable
    form_class = HtableForm


class HtableDetailView(DetailView):
    model = Htable


class HtableUpdateView(UpdateView):
    model = Htable
    form_class = HtableForm


class RtpEngineListView(ListView):
    model = RtpEngine


class RtpEngineCreateView(CreateView):
    model = RtpEngine
    form_class = RtpEngineForm


class RtpEngineDetailView(DetailView):
    model = RtpEngine


class RtpEngineUpdateView(UpdateView):
    model = RtpEngine
    form_class = RtpEngineForm


class StatisticListView(ListView):
    model = Statistic


class StatisticCreateView(CreateView):
    model = Statistic
    form_class = StatisticForm


class StatisticDetailView(DetailView):
    model = Statistic


class StatisticUpdateView(UpdateView):
    model = Statistic
    form_class = StatisticForm



# -*- coding: utf-8 -*-
from django import forms
from .models import Dialog, DialogVar, Acc, AccCdr, MissedCall, UacReg, Trusted, Version, Location, LocationAttrs, UserBlackList, GlobalBlackList, SpeedDial, PipeLimit, Mtree, Mtrees, Htable, RtpEngine, Statistic


class DialogForm(forms.ModelForm):
    class Meta:
        model = Dialog
        fields = ['hash_entry', 'hash_id', 'callid', 'from_uri', 'from_tag', 'to_uri', 'to_tag', 'caller_cseq', 'callee_cseq', 'caller_route_set', 'callee_route_set', 'caller_contact', 'callee_contact', 'caller_sock', 'callee_sock', 'state', 'start_time', 'timeout', 'sflags', 'iflags', 'toroute_name', 'req_uri', 'xdata']


class DialogVarForm(forms.ModelForm):
    class Meta:
        model = DialogVar
        fields = ['hash_entry', 'hash_id', 'dialog_key', 'dialog_value']


class AccForm(forms.ModelForm):
    class Meta:
        model = Acc
        fields = ['method', 'from_tag', 'to_tag', 'callid', 'sip_code', 'sip_reason', 'time', 'time_attr', 'time_exten']


class AccCdrForm(forms.ModelForm):
    class Meta:
        model = AccCdr
        fields = ['start_time', 'end_time', 'duration']


class MissedCallForm(forms.ModelForm):
    class Meta:
        model = MissedCall
        fields = ['method', 'from_tag', 'to_tag', 'callid', 'sip_code', 'sip_reason', 'time']


class UacRegForm(forms.ModelForm):
    class Meta:
        model = UacReg
        fields = ['l_uuid', 'l_username', 'l_domain', 'r_username', 'r_domain', 'realm', 'auth_username', 'auth_password', 'auth_ha1', 'auth_proxy', 'expires', 'flags', 'reg_delay']


class TrustedForm(forms.ModelForm):
    class Meta:
        model = Trusted
        fields = ['src_ip', 'proto', 'from_pattern', 'ruri_pattern', 'tag', 'priority']


class VersionForm(forms.ModelForm):
    class Meta:
        model = Version
        fields = ['table_name', 'table_version']


class LocationForm(forms.ModelForm):
    class Meta:
        model = Location
        fields = ['ruid', 'username', 'domain', 'contact', 'received', 'path', 'expires', 'q', 'callid', 'cseq', 'last_modified', 'flags', 'cflags', 'user_agent', 'socket', 'methods', 'instance', 'reg_id', 'server_id', 'connection_id', 'keepalive', 'partition']


class LocationAttrsForm(forms.ModelForm):
    class Meta:
        model = LocationAttrs
        fields = ['ruid', 'username', 'domain', 'aname', 'atype', 'avalue', 'last_modified']


class UserBlackListForm(forms.ModelForm):
    class Meta:
        model = UserBlackList
        fields = ['username', 'domain', 'prefix', 'whitelist']


class GlobalBlackListForm(forms.ModelForm):
    class Meta:
        model = GlobalBlackList
        fields = ['prefix', 'whitelist', 'description']


class SpeedDialForm(forms.ModelForm):
    class Meta:
        model = SpeedDial
        fields = ['username', 'domain', 'sd_username', 'sd_domain', 'new_uri', 'fname', 'lname', 'description']


class PipeLimitForm(forms.ModelForm):
    class Meta:
        model = PipeLimit
        fields = ['pipeid', 'algorithm', 'plimit']


class MtreeForm(forms.ModelForm):
    class Meta:
        model = Mtree
        fields = ['tprefix', 'tvalue']


class MtreesForm(forms.ModelForm):
    class Meta:
        model = Mtrees
        fields = ['tname', 'tprefix', 'tvalue']


class HtableForm(forms.ModelForm):
    class Meta:
        model = Htable
        fields = ['key_name', 'key_type', 'value_type', 'key_value', 'expires']


class RtpEngineForm(forms.ModelForm):
    class Meta:
        model = RtpEngine
        fields = ['setid', 'url', 'weight', 'disabled']


class StatisticForm(forms.ModelForm):
    class Meta:
        model = Statistic
        fields = ['kamailio_id', 'time_stamp', 'random', 'shm_used_size', 'shm_real_used_size', 'shm_max_used_size', 'shm_free_used_size', 'ul_users', 'ul_contacts']



# -*- coding: utf-8 -*-
from . import models

from rest_framework import serializers


class DialogSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Dialog
        fields = (
            'pk',
            'hash_entry',
            'hash_id',
            'callid',
            'from_uri',
            'from_tag',
            'to_uri',
            'to_tag',
            'caller_cseq',
            'callee_cseq',
            'caller_route_set',
            'callee_route_set',
            'caller_contact',
            'callee_contact',
            'caller_sock',
            'callee_sock',
            'state',
            'start_time',
            'timeout',
            'sflags',
            'iflags',
            'toroute_name',
            'req_uri',
            'xdata',
        )


class DialogVarSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.DialogVar
        fields = (
            'pk',
            'hash_entry',
            'hash_id',
            'dialog_key',
            'dialog_value',
        )


class AccSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Acc
        fields = (
            'pk',
            'method',
            'from_tag',
            'to_tag',
            'callid',
            'sip_code',
            'sip_reason',
            'time',
            'time_attr',
            'time_exten',
        )


class AccCdrSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.AccCdr
        fields = (
            'pk',
            'start_time',
            'end_time',
            'duration',
        )


class MissedCallSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.MissedCall
        fields = (
            'pk',
            'method',
            'from_tag',
            'to_tag',
            'callid',
            'sip_code',
            'sip_reason',
            'time',
        )


class UacRegSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.UacReg
        fields = (
            'pk',
            'l_uuid',
            'l_username',
            'l_domain',
            'r_username',
            'r_domain',
            'realm',
            'auth_username',
            'auth_password',
            'auth_ha1',
            'auth_proxy',
            'expires',
            'flags',
            'reg_delay',
        )


class TrustedSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Trusted
        fields = (
            'pk',
            'src_ip',
            'proto',
            'from_pattern',
            'ruri_pattern',
            'tag',
            'priority',
        )


class VersionSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Version
        fields = (
            'pk',
            'table_name',
            'table_version',
        )


class LocationSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Location
        fields = (
            'pk',
            'ruid',
            'username',
            'domain',
            'contact',
            'received',
            'path',
            'expires',
            'q',
            'callid',
            'cseq',
            'last_modified',
            'flags',
            'cflags',
            'user_agent',
            'socket',
            'methods',
            'instance',
            'reg_id',
            'server_id',
            'connection_id',
            'keepalive',
            'partition',
        )


class LocationAttrsSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.LocationAttrs
        fields = (
            'pk',
            'ruid',
            'username',
            'domain',
            'aname',
            'atype',
            'avalue',
            'last_modified',
        )


class UserBlackListSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.UserBlackList
        fields = (
            'pk',
            'username',
            'domain',
            'prefix',
            'whitelist',
        )


class GlobalBlackListSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.GlobalBlackList
        fields = (
            'pk',
            'prefix',
            'whitelist',
            'description',
        )


class SpeedDialSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.SpeedDial
        fields = (
            'pk',
            'username',
            'domain',
            'sd_username',
            'sd_domain',
            'new_uri',
            'fname',
            'lname',
            'description',
        )


class PipeLimitSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.PipeLimit
        fields = (
            'pk',
            'pipeid',
            'algorithm',
            'plimit',
        )


class MtreeSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Mtree
        fields = (
            'pk',
            'tprefix',
            'tvalue',
        )


class MtreesSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Mtrees
        fields = (
            'pk',
            'tname',
            'tprefix',
            'tvalue',
        )


class HtableSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Htable
        fields = (
            'pk',
            'key_name',
            'key_type',
            'value_type',
            'key_value',
            'expires',
        )


class RtpEngineSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.RtpEngine
        fields = (
            'pk',
            'setid',
            'url',
            'weight',
            'disabled',
            'stamp',
        )


class StatisticSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.Statistic
        fields = (
            'pk',
            'kamailio_id',
            'time_stamp',
            'random',
            'shm_used_size',
            'shm_real_used_size',
            'shm_max_used_size',
            'shm_free_used_size',
            'ul_users',
            'ul_contacts',
        )



# -*- coding: utf-8 -*-
from django.urls import path, include
from rest_framework import routers

from . import api
from . import views

app_name = 'pyfb_kamailio'

router = routers.DefaultRouter()
router.register(r'dialog', api.DialogViewSet)
router.register(r'dialogvar', api.DialogVarViewSet)
router.register(r'acc', api.AccViewSet)
router.register(r'acccdr', api.AccCdrViewSet)
router.register(r'missedcall', api.MissedCallViewSet)
router.register(r'uacreg', api.UacRegViewSet)
router.register(r'trusted', api.TrustedViewSet)
router.register(r'version', api.VersionViewSet)
router.register(r'location', api.LocationViewSet)
router.register(r'locationattrs', api.LocationAttrsViewSet)
router.register(r'userblacklist', api.UserBlackListViewSet)
router.register(r'globalblacklist', api.GlobalBlackListViewSet)
router.register(r'speeddial', api.SpeedDialViewSet)
router.register(r'pipelimit', api.PipeLimitViewSet)
router.register(r'mtree', api.MtreeViewSet)
router.register(r'mtrees', api.MtreesViewSet)
router.register(r'htable', api.HtableViewSet)
router.register(r'rtpengine', api.RtpEngineViewSet)

urlpatterns = (
    # urls for Django Rest Framework API
    path('api/v1/', include(router.urls)),
)

urlpatterns += (
    # urls for Dialog
    path('pyfb_kamailio/dialog/', views.DialogListView.as_view(), name='pyfb_kamailio_dialog_list'),
    path('pyfb_kamailio/dialog/create/', views.DialogCreateView.as_view(), name='pyfb_kamailio_dialog_create'),
    path('pyfb_kamailio/dialog/detail/<int:pk>/', views.DialogDetailView.as_view(), name='pyfb_kamailio_dialog_detail'),
    path('pyfb_kamailio/dialog/update/<int:pk>/', views.DialogUpdateView.as_view(), name='pyfb_kamailio_dialog_update'),
)

urlpatterns += (
    # urls for DialogVar
    path('pyfb_kamailio/dialogvar/', views.DialogVarListView.as_view(), name='pyfb_kamailio_dialogvar_list'),
    path('pyfb_kamailio/dialogvar/create/', views.DialogVarCreateView.as_view(), name='pyfb_kamailio_dialogvar_create'),
    path('pyfb_kamailio/dialogvar/detail/<int:pk>/', views.DialogVarDetailView.as_view(), name='pyfb_kamailio_dialogvar_detail'),
    path('pyfb_kamailio/dialogvar/update/<int:pk>/', views.DialogVarUpdateView.as_view(), name='pyfb_kamailio_dialogvar_update'),
)

urlpatterns += (
    # urls for Acc
    path('pyfb_kamailio/acc/', views.AccListView.as_view(), name='pyfb_kamailio_acc_list'),
    path('pyfb_kamailio/acc/create/', views.AccCreateView.as_view(), name='pyfb_kamailio_acc_create'),
    path('pyfb_kamailio/acc/detail/<int:pk>/', views.AccDetailView.as_view(), name='pyfb_kamailio_acc_detail'),
    path('pyfb_kamailio/acc/update/<int:pk>/', views.AccUpdateView.as_view(), name='pyfb_kamailio_acc_update'),
)

urlpatterns += (
    # urls for AccCdr
    path('pyfb_kamailio/acccdr/', views.AccCdrListView.as_view(), name='pyfb_kamailio_acccdr_list'),
    path('pyfb_kamailio/acccdr/create/', views.AccCdrCreateView.as_view(), name='pyfb_kamailio_acccdr_create'),
    path('pyfb_kamailio/acccdr/detail/<int:pk>/', views.AccCdrDetailView.as_view(), name='pyfb_kamailio_acccdr_detail'),
    path('pyfb_kamailio/acccdr/update/<int:pk>/', views.AccCdrUpdateView.as_view(), name='pyfb_kamailio_acccdr_update'),
)

urlpatterns += (
    # urls for MissedCall
    path('pyfb_kamailio/missedcall/', views.MissedCallListView.as_view(), name='pyfb_kamailio_missedcall_list'),
    path('pyfb_kamailio/missedcall/create/', views.MissedCallCreateView.as_view(), name='pyfb_kamailio_missedcall_create'),
    path('pyfb_kamailio/missedcall/detail/<int:pk>/', views.MissedCallDetailView.as_view(), name='pyfb_kamailio_missedcall_detail'),
    path('pyfb_kamailio/missedcall/update/<int:pk>/', views.MissedCallUpdateView.as_view(), name='pyfb_kamailio_missedcall_update'),
)

urlpatterns += (
    # urls for UacReg
    path('pyfb_kamailio/uacreg/', views.UacRegListView.as_view(), name='pyfb_kamailio_uacreg_list'),
    path('pyfb_kamailio/uacreg/create/', views.UacRegCreateView.as_view(), name='pyfb_kamailio_uacreg_create'),
    path('pyfb_kamailio/uacreg/detail/<int:pk>/', views.UacRegDetailView.as_view(), name='pyfb_kamailio_uacreg_detail'),
    path('pyfb_kamailio/uacreg/update/<int:pk>/', views.UacRegUpdateView.as_view(), name='pyfb_kamailio_uacreg_update'),
)

urlpatterns += (
    # urls for Trusted
    path('pyfb_kamailio/trusted/', views.TrustedListView.as_view(), name='pyfb_kamailio_trusted_list'),
    path('pyfb_kamailio/trusted/create/', views.TrustedCreateView.as_view(), name='pyfb_kamailio_trusted_create'),
    path('pyfb_kamailio/trusted/detail/<int:pk>/', views.TrustedDetailView.as_view(), name='pyfb_kamailio_trusted_detail'),
    path('pyfb_kamailio/trusted/update/<int:pk>/', views.TrustedUpdateView.as_view(), name='pyfb_kamailio_trusted_update'),
)

urlpatterns += (
    # urls for Version
    path('pyfb_kamailio/version/', views.VersionListView.as_view(), name='pyfb_kamailio_version_list'),
    path('pyfb_kamailio/version/create/', views.VersionCreateView.as_view(), name='pyfb_kamailio_version_create'),
    path('pyfb_kamailio/version/detail/<int:pk>/', views.VersionDetailView.as_view(), name='pyfb_kamailio_version_detail'),
    path('pyfb_kamailio/version/update/<int:pk>/', views.VersionUpdateView.as_view(), name='pyfb_kamailio_version_update'),
)

urlpatterns += (
    # urls for Location
    path('pyfb_kamailio/location/', views.LocationListView.as_view(), name='pyfb_kamailio_location_list'),
    path('pyfb_kamailio/location/create/', views.LocationCreateView.as_view(), name='pyfb_kamailio_location_create'),
    path('pyfb_kamailio/location/detail/<int:pk>/', views.LocationDetailView.as_view(), name='pyfb_kamailio_location_detail'),
    path('pyfb_kamailio/location/update/<int:pk>/', views.LocationUpdateView.as_view(), name='pyfb_kamailio_location_update'),
)

urlpatterns += (
    # urls for LocationAttrs
    path('pyfb_kamailio/locationattrs/', views.LocationAttrsListView.as_view(), name='pyfb_kamailio_locationattrs_list'),
    path('pyfb_kamailio/locationattrs/create/', views.LocationAttrsCreateView.as_view(), name='pyfb_kamailio_locationattrs_create'),
    path('pyfb_kamailio/locationattrs/detail/<int:pk>/', views.LocationAttrsDetailView.as_view(), name='pyfb_kamailio_locationattrs_detail'),
    path('pyfb_kamailio/locationattrs/update/<int:pk>/', views.LocationAttrsUpdateView.as_view(), name='pyfb_kamailio_locationattrs_update'),
)

urlpatterns += (
    # urls for UserBlackList
    path('pyfb_kamailio/userblacklist/', views.UserBlackListListView.as_view(), name='pyfb_kamailio_userblacklist_list'),
    path('pyfb_kamailio/userblacklist/create/', views.UserBlackListCreateView.as_view(), name='pyfb_kamailio_userblacklist_create'),
    path('pyfb_kamailio/userblacklist/detail/<int:pk>/', views.UserBlackListDetailView.as_view(), name='pyfb_kamailio_userblacklist_detail'),
    path('pyfb_kamailio/userblacklist/update/<int:pk>/', views.UserBlackListUpdateView.as_view(), name='pyfb_kamailio_userblacklist_update'),
)

urlpatterns += (
    # urls for GlobalBlackList
    path('pyfb_kamailio/globalblacklist/', views.GlobalBlackListListView.as_view(), name='pyfb_kamailio_globalblacklist_list'),
    path('pyfb_kamailio/globalblacklist/create/', views.GlobalBlackListCreateView.as_view(), name='pyfb_kamailio_globalblacklist_create'),
    path('pyfb_kamailio/globalblacklist/detail/<int:pk>/', views.GlobalBlackListDetailView.as_view(), name='pyfb_kamailio_globalblacklist_detail'),
    path('pyfb_kamailio/globalblacklist/update/<int:pk>/', views.GlobalBlackListUpdateView.as_view(), name='pyfb_kamailio_globalblacklist_update'),
)

urlpatterns += (
    # urls for SpeedDial
    path('pyfb_kamailio/speeddial/', views.SpeedDialListView.as_view(), name='pyfb_kamailio_speeddial_list'),
    path('pyfb_kamailio/speeddial/create/', views.SpeedDialCreateView.as_view(), name='pyfb_kamailio_speeddial_create'),
    path('pyfb_kamailio/speeddial/detail/<int:pk>/', views.SpeedDialDetailView.as_view(), name='pyfb_kamailio_speeddial_detail'),
    path('pyfb_kamailio/speeddial/update/<int:pk>/', views.SpeedDialUpdateView.as_view(), name='pyfb_kamailio_speeddial_update'),
)

urlpatterns += (
    # urls for PipeLimit
    path('pyfb_kamailio/pipelimit/', views.PipeLimitListView.as_view(), name='pyfb_kamailio_pipelimit_list'),
    path('pyfb_kamailio/pipelimit/create/', views.PipeLimitCreateView.as_view(), name='pyfb_kamailio_pipelimit_create'),
    path('pyfb_kamailio/pipelimit/detail/<int:pk>/', views.PipeLimitDetailView.as_view(), name='pyfb_kamailio_pipelimit_detail'),
    path('pyfb_kamailio/pipelimit/update/<int:pk>/', views.PipeLimitUpdateView.as_view(), name='pyfb_kamailio_pipelimit_update'),
)

urlpatterns += (
    # urls for Mtree
    path('pyfb_kamailio/mtree/', views.MtreeListView.as_view(), name='pyfb_kamailio_mtree_list'),
    path('pyfb_kamailio/mtree/create/', views.MtreeCreateView.as_view(), name='pyfb_kamailio_mtree_create'),
    path('pyfb_kamailio/mtree/detail/<int:pk>/', views.MtreeDetailView.as_view(), name='pyfb_kamailio_mtree_detail'),
    path('pyfb_kamailio/mtree/update/<int:pk>/', views.MtreeUpdateView.as_view(), name='pyfb_kamailio_mtree_update'),
)

urlpatterns += (
    # urls for Mtrees
    path('pyfb_kamailio/mtrees/', views.MtreesListView.as_view(), name='pyfb_kamailio_mtrees_list'),
    path('pyfb_kamailio/mtrees/create/', views.MtreesCreateView.as_view(), name='pyfb_kamailio_mtrees_create'),
    path('pyfb_kamailio/mtrees/detail/<int:pk>/', views.MtreesDetailView.as_view(), name='pyfb_kamailio_mtrees_detail'),
    path('pyfb_kamailio/mtrees/update/<int:pk>/', views.MtreesUpdateView.as_view(), name='pyfb_kamailio_mtrees_update'),
)

urlpatterns += (
    # urls for Htable
    path('pyfb_kamailio/htable/', views.HtableListView.as_view(), name='pyfb_kamailio_htable_list'),
    path('pyfb_kamailio/htable/create/', views.HtableCreateView.as_view(), name='pyfb_kamailio_htable_create'),
    path('pyfb_kamailio/htable/detail/<int:pk>/', views.HtableDetailView.as_view(), name='pyfb_kamailio_htable_detail'),
    path('pyfb_kamailio/htable/update/<int:pk>/', views.HtableUpdateView.as_view(), name='pyfb_kamailio_htable_update'),
)

urlpatterns += (
    # urls for RtpEngine
    path('pyfb_kamailio/rtpengine/', views.RtpEngineListView.as_view(), name='pyfb_kamailio_rtpengine_list'),
    path('pyfb_kamailio/rtpengine/create/', views.RtpEngineCreateView.as_view(), name='pyfb_kamailio_rtpengine_create'),
    path('pyfb_kamailio/rtpengine/detail/<int:pk>/', views.RtpEngineDetailView.as_view(), name='pyfb_kamailio_rtpengine_detail'),
    path('pyfb_kamailio/rtpengine/update/<int:pk>/', views.RtpEngineUpdateView.as_view(), name='pyfb_kamailio_rtpengine_update'),
)

urlpatterns += (
    # urls for Statistic
    path('pyfb_kamailio/statistic/', views.StatisticListView.as_view(), name='pyfb_kamailio_statistic_list'),
    path('pyfb_kamailio/statistic/create/', views.StatisticCreateView.as_view(), name='pyfb_kamailio_statistic_create'),
    path('pyfb_kamailio/statistic/detail/<int:pk>/', views.StatisticDetailView.as_view(), name='pyfb_kamailio_statistic_detail'),
    path('pyfb_kamailio/statistic/update/<int:pk>/', views.StatisticUpdateView.as_view(), name='pyfb_kamailio_statistic_update'),
)



# Generated by Django 2.1.5 on 2019-03-06 15:14

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0006_toposd_topost'),
    ]

    operations = [
        migrations.AddField(
            model_name='missedcall',
            name='cseq',
            field=models.CharField(default='', help_text='cseq field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='from_domain',
            field=models.CharField(default='', help_text='FROM domain field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='from_user',
            field=models.CharField(default='', help_text='FROM user field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='ruri_domain',
            field=models.CharField(default='', help_text='RURI domain field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='ruri_user',
            field=models.CharField(default='', help_text='RURI user field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='src_ip',
            field=models.CharField(default='', help_text='source IP', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='time_attr',
            field=models.IntegerField(default=1, help_text='Unix timestamp'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='missedcall',
            name='time_exten',
            field=models.IntegerField(default=0, help_text='extended value related to the time of event'),
            preserve_default=False,
        ),
    ]



XXXXXXXXXXX
XXXXXXXXXXXXXXXX
XXXXXXXXXXX
XXXXXXX
XXXXXXXXXXX
XXXXXXXXXX
XXXXXXXXX
XXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX